==> kubernetes-client-4.13.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/apps/v1/DaemonSetOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.apps.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.apps.DoneableDaemonSet;
import io.fabric8.kubernetes.api.model.apps.DaemonSet;
import io.fabric8.kubernetes.api.model.apps.DaemonSetList;
import io.fabric8.kubernetes.api.model.apps.DoneableDaemonSet;

import java.util.Map;
import java.util.TreeMap;


public class DaemonSetOperationsImpl extends HasMetadataOperation<DaemonSet, DaemonSetList, DoneableDaemonSet, Resource<DaemonSet, DoneableDaemonSet>> {

  public DaemonSetOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public DaemonSetOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public DaemonSetOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("apps")
    .withApiGroupVersion("v1")
    .withPlural("daemonsets"));
    this.type = DaemonSet.class;
    this.listType = DaemonSetList.class;
    this.doneableType = DoneableDaemonSet.class;
  }

  public DaemonSetOperationsImpl newInstance(OperationContext context) {
    return new DaemonSetOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.2.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/apps/v1/DaemonSetOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.apps.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.apps.DaemonSet;
import io.fabric8.kubernetes.api.model.apps.DaemonSetBuilder;
import io.fabric8.kubernetes.api.model.apps.DaemonSetList;

import java.util.Map;
import java.util.TreeMap;


public class DaemonSetOperationsImpl extends HasMetadataOperation<DaemonSet, DaemonSetList, Resource<DaemonSet>> {

  public DaemonSetOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public DaemonSetOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public DaemonSetOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("apps")
    .withApiGroupVersion("v1")
    .withPlural("daemonsets"));
    this.type = DaemonSet.class;
    this.listType = DaemonSetList.class;
  }

  public DaemonSetOperationsImpl newInstance(OperationContext context) {
    return new DaemonSetOperationsImpl(context);
  }

  @Override
  public DaemonSet edit(Visitor... visitors) {
    return patch(new DaemonSetBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
